% loads (1) a structure "Example" containing the squeleton of the ETG and
% the names of the different nodes and (2) a structure of two costs, each
% cost is itself a structure with three required fields (Squelette defining
% the relations between the cost squeleton and the model squeleton
% (usually, Squelette(i,j) contains (i,j), direct correspondance between
% both matrices) but such a trick permits to study some more general cases
% of costs (that may corresponds to paths if the model squeleton). The
% second required field is the impact matrix (same size as Squelette). The
% third field corresponds to the type of cost (0= additive,
% 1=multiplicative), i.e., how the elementary impacts are cumulated to
% obtain the cost of a trajectory.

load Simple_example_ETG


% First part:
% Determination of the active degradation cost for protein X

% set the uniform transition matrix
Uniform_Transition = Example.squeleton./(sum(Example.squeleton,2)*ones(1,length(Example.squeleton)));

figure(1);
% Draws the "uniform model"
draw_dot2(Example.squeleton, Uniform_Transition, Example.names);

% Steady-state matrix associated to the uniform model (easier to use powers
% than to use eigs function for computing the steady-state dist)
PI=Uniform_Transition^100; PI=PI(1,:);
% have to solve equation : x*PI(3) + 1/x*PI(1) + 0.95*(1-PI(1)-PI(3)) = 1
delta= (0.95*(1-PI(1)-PI(3)) - 1)^2-4*PI(3)*PI(1);
sol1= (- (0.95*(1-PI(1)-PI(3)) - 1) + sqrt(delta))/(2*PI(3));
sol2= (- (0.95*(1-PI(1)-PI(3)) - 1) - sqrt(delta))/(2*PI(3));
disp('Computing the active degradation rate for protein X...')
disp(sprintf('Two solutions %f and %f. Keep  the second %f\n', sol1, sol2, sol2));

% Construction of the impact matrix for protein X
Costs{1}.Cout(:,1)=1/sol2; Costs{1}.Cout(:,2)=0.95; Costs{1}.Cout(:,3)=sol2; Costs{1}.Cout(:,4)=0.95;
% Construction of the impact matrix for protein Y (same elementary cost).
Costs{2}.Cout(:,2)=1/sol2; Costs{2}.Cout(:,1)=0.95; Costs{2}.Cout(:,4)=sol2; Costs{2}.Cout(:,3)=0.95;

disp('Verification...');
disp(sprintf('The asymptotic growth rate for protein X is %f\n', EuclideanScore(Uniform_Transition, Costs([1]), {0} ) ));

% Distribution of the Wild-Type model (i.e., all transition matrix that
% satisfies the model squeleton are equally likely). Draws 10000 transition
% matrices and compute the asymptotic growth rate for protein Y.

values=[]; for i=1:10000 TM=RandomTransition(Example.squeleton); values=[values EuclideanScore(TM, Costs([2]), {0} )]; end;
range=min([min(Costs{1}.Cout) min(Costs{2}.Cout)]):0.01:max([max(Costs{1}.Cout) max(Costs{2}.Cout)]);
WThist=hist(values,range);
WThist=WThist/10000;
figure(2);
bar(range,WThist);
title('Wild-type distribution for protein Y growth ratio');

% Distribution of the constrained model (Protein X Growth Ratio (GR) fixed
% to 1.1.
% Take nbpoints points in the solution set.

nbpoints=1000;
values=[]; for i=1:nbpoints disp(sprintf('Compute point number %d',i)); [Score,TM]=ETG_solve(Example.squeleton, Costs([1]), {1.1}, 10e-4,0); values=[values EuclideanScore(TM, Costs([2]), {0} )]; end;
CMhist1=hist(values,range);
CMhist1=CMhist1/nbpoints;
figure(3);
bar(range,CMhist1);
title('distribution for protein Y growth ratio when Protein X GR=1.1');

disp(sprintf('Average growth rate for protein Y (when Protein X GR=1.1) = %f\n',mean(values)));

figure(4);
bar(range,CMhist1-WThist);
title('distribution differences for protein Y growth ratio between WT and case when Protein X GR=1.1');

% Distribution of the constrained model (Protein X Growth Ratio (GR) fixed
% to 0.97
% Take nbpoints points in the solution set.

nbpoints=1000;
values=[]; for i=1:nbpoints disp(sprintf('Compute point number %d',i)); [Score,TM]=ETG_solve(Example.squeleton, Costs([1]), {0.97}, 10e-4,0); values=[values EuclideanScore(TM, Costs([2]), {0} )]; end;
CMhist2=hist(values,range);
CMhist2=CMhist2/nbpoints;
figure(5);
bar(range,CMhist1);
title('distribution for protein Y growth ratio when Protein X GR=0.97');

disp(sprintf('Average growth rate for protein Y (when Protein X GR=0.97) = %f\n',mean(values)));

figure(6);
bar(range,CMhist2-WThist);
title('distribution differences for protein Y growth ratio between WT and case when Protein X GR=0.97');



