load VraiColi
load experiment

%% in accordance to the N-end rule [Alexander, Varshavsky (1997). "The N-end rule pathway of protein degradation". Genes to Cells 2 (1): 13-28]
%% According to http://protein-n-end-rule.tk/ , the half-life of Fis and
%% Cya is > 10h.... But we are not interesting in its "complete"
%% degradation, we are only interested in its neutralisation that arises
%% as soon as several of its AA are degradated. This duration is ~2min.
%% Here, the main difference is whether one considers the max degradation
%% time of an AA (>10h) or the min degradation time of an AA (2min).
disp('Transition duration');
disp('=============================================');
disp('The N-end rule provides the minimal half-life of aminoacids');
disp('half-life=2 minutes. Assuming a natural degradation rate of 5%,');
disp('There is log(0.5)/(2*log(0.95))=6.7567 iterations/minutes.');
disp('Each iteration has a duration of 0.148 minutes.');
disp('');
n=round(log(0.5)/log(0.95)/2); %% n=number of iterations per minute

disp('Goals');
disp('=============================================');
disp('Three points are used in FIS concentration time series : (2,10), (80,100) et (130,10)');
goals = {exp((log(fis(6,2))-log(fis(2,2)))/((fis(6,1)-fis(2,1))*n)), exp((log(fis(9,2))-log(fis(6,2)))/((fis(9,1)-fis(6,1))*n))}
disp('');

disp('Computation of several consistent matrices from the solution set');
disp('=============================================');

nbtests_total=200; % maximal number of tests to be performed
nbtests_for_average=100; % Total number of tests for the averaging the predicted growth ratios
nbtests=0; % Number of consistent computed solutions

SENS=zeros(length(CompleteColi.squeleton),length(CompleteColi.squeleton)); %% initialisation of the sensibility
for i=1:length(TousCoutsPrint) distCouts{i}=[]; end; %% initialisation for all growth ratios

while ((nbtests_total>0) && (nbtests<nbtests_for_average))
    fprintf('Computing solution no %d : begin.',nbtests+1);
    [BS,BM]=ETG_solve(CompleteColi.squeleton, TousCoutsPrint([1 2]), goals, 10e-5, 0);
    fprintf('.end: the solution is ');
    nbtests_total=nbtests_total-1;
    if (BS<10e-4) %% to ensure that the algorithm had converged
        for i=1:length(TousCoutsPrint) distCouts{i}=[distCouts{i} EuclideanScore(BM,TousCoutsPrint([i]),{0})]; end;
        SENS=SENS+Sensibility(BM, TousCoutsPrint([1 2]), goals);
        if (nbtests == 0)
            figure(1);
            draw_dot2(CompleteColi.squeleton,BM,CompleteColi.names);
            title('An example of consistent transition matrix');
        end;
        nbtests=nbtests+1;
        fprintf('consistent\n');
    else
        fprintf('not consistent\n');
    end;

end;

%% print the sensibility
figure(2);
SENS=SENS/nbtests;
[sx,sy]=size(SENS); for i=1:sx for j=1:sy if (SENS(i,j)>0) if (SENS(i,j)<0.01) arclabels{i,j}=sprintf('<1%%'); else arclabels{i,j}=sprintf('%.1f%%',SENS(i,j)*100); end; else arclabels{i,j}=''; end; end; end;
draw_dot_pretty(CompleteColi.squeleton, arclabels, CompleteColi.names);


%% Print all the average growth ratios
fprintf('%50s\t%10s\t%10s\n','Growth ratio name','Mean','Stddev');
for i=1:length(TousCoutsPrint) 
    fprintf('%50s\t%10s\t%10s\n',TousCoutsPrint{i}.Name,sprintf('%.5f',mean(distCouts{i})), sprintf('%.5f',std(distCouts{i})) );
end;

%% Computation of the predicted time series
Range_stationary=0:80;
Range_exponential=81:130;

Represented_proteins={'FIS','CYA','TOP A','GYR AB','CRP'};
%% initial values of protein concentrations (notice that the first point 
%% for FIS concentration (0,75) is omitted because it appears to be inconsistent
%% with the assumption of some exponential decays of protein concentrations)

initial_values=[10,75,50,50,50]; 

for i=1:length(Represented_proteins) 
    timeserie{i}=[];
    growth_ratio_stationary_phase=mean(distCouts{2*i-1});
    growth_ratio_exponential_phase=mean(distCouts{2*i});
    for t=Range_stationary
        timeserie{i}=[timeserie{i} max( 1 , min ( 100, initial_values(i)* growth_ratio_stationary_phase^((t-Range_stationary(1))*n) ))];
    end;
    initial_value_exponential=timeserie{i}(max(Range_stationary));
    for t=Range_exponential
        timeserie{i}=[timeserie{i} max( 1 , min ( 100, initial_value_exponential * growth_ratio_exponential_phase^((t-Range_exponential(1))*n) ))];
    end;
end;

%% Picture predictions for CYA
figure(3);
phase = [0 0 100 100;0 79.9999 80 140];
area(phase(2,:), phase(1,:),'FaceColor',[.75,.75,1])
hold on;
xlabel('Time(min)');
ylabel('Percentage of the maximal concentration');

plot(fis(:,1), fis(:,2) , 'bs', 'Markersize', 10, 'MarkerFaceColor','b');
plot(cya(:,1), cya(:,2) , 'bo', 'Markersize', 10, 'MarkerFaceColor','r');
plot([Range_stationary Range_exponential], timeserie{1}, 'b-');
plot([Range_stationary Range_exponential], timeserie{2}, 'r-');
legend('No starvation','FIS obs', 'CYA obs', 'FIS pred', 'CYA pred')
hold off;

figure(4);
area(phase(2,:), phase(1,:),'FaceColor',[.75,.75,1])
hold on;
xlabel('Time(min)');
ylabel('Percentage of the maximal concentration');

plot(fis(:,1), fis(:,2) , 'bs', 'Markersize', 10, 'MarkerFaceColor','b');
plot(cya(:,1), cya(:,2) , 'bo', 'Markersize', 10, 'MarkerFaceColor','r');
plot([Range_stationary Range_exponential], timeserie{1}, 'b-');
plot([Range_stationary Range_exponential], timeserie{2}, 'r-');
plot([Range_stationary Range_exponential], timeserie{3}, 'g--');
plot([Range_stationary Range_exponential], timeserie{4}, 'y--');
plot([Range_stationary Range_exponential], timeserie{5}, 'c--');
legend('No starvation','FIS obs', 'CYA obs', 'FIS pred', 'CYA pred', 'TOP A pred', 'GYR AB pred', 'CRP pred');
hold off;

